@@ -1,4 +1,5 @@
-from .. import CoreService_pb2 as pb
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
+
 from ..entities.ingest import Ingest
 
 
