@@ -1,12 +1,14 @@
 from typing import List
 
-from .. import CoreService_pb2 as pb
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
+
 from ..entities.base_job import BaseJob
 from ..entities.compute_statistics_job import ComputeStatisticsJob
 from ..entities.extract_schema_job import ExtractSchemaJob
 from ..entities.ingest_job import IngestJob
 from ..entities.materialization_online_job import MaterializationOnlineJob
 from ..entities.retrieve_job import RetrieveJob
+from ..entities.revert_ingest_job import RevertIngestJob
 
 
 class Jobs:
@@ -26,6 +28,8 @@ class Jobs:
             return MaterializationOnlineJob(stub, job_id)
         elif job_proto.job_type == pb.JobType.ComputeStatistics:
             return ComputeStatisticsJob(stub, job_id)
+        elif job_proto.job_type == pb.JobType.Revert:
+            return RevertIngestJob(stub, job_id)
 
     def list(self, active=True, job_type=pb.JobType.Unknown) -> List[BaseJob]:
         request = pb.ListJobsRequest(active=active, job_type=job_type)
