@@ -1,9 +1,6 @@
-import shutil
-import tempfile
-
-import featurestore.core.CoreService_pb2 as pb
-import featurestore.core.FeatureSetSearch_pb2 as pb_search
-from featurestore.core.FeatureSetSearch_pb2 import (
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
+import ai.h2o.featurestore.api.v1.FeatureSetSearch_pb2 as pb_search
+from ai.h2o.featurestore.api.v1.FeatureSetSearch_pb2 import (
     BooleanFilter,
     NumericalFilter,
     TextualFilter,
@@ -217,29 +214,6 @@ class SnowflakeCursor:
         return latest_query
 
 
-class DriverlessAIMOJO:
-    def __init__(self, feature_set, mojo):
-        self.input = feature_set
-        with open(mojo, mode="rb") as file:
-            self.data = file.read()
-
-
-class SparkPipeline:
-    def __init__(self, feature_set, pipeline):
-        if isinstance(pipeline, str) and pipeline.endswith(".zip"):
-            self.data = open(pipeline, "rb").read()
-        elif isinstance(pipeline, str):
-            shutil.make_archive("pipeline", "zip", pipeline)
-            self.data = open("pipeline.zip", "rb").read()
-        else:
-            output_dir = tempfile.mkdtemp()
-            pipeline.write().overwrite().save(output_dir)
-            shutil.make_archive("pipeline", "zip", output_dir)
-            self.data = open("pipeline.zip", "rb").read()
-            shutil.rmtree(output_dir)
-        self.input = feature_set
-
-
 class DeltaTable:
     def __init__(self, path, version=-1, timestamp=None, filter=None):
         self.path = path
@@ -250,27 +224,6 @@ class DeltaTable:
             raise ValueError("Only one of version or timestamp is supported")
 
 
-class JoinedFeatureSets:
-    def __init__(self, left, right, join_key):
-        self.left = left
-        self.right = right
-        self.join_key = join_key
-        if (
-            join_key.lower() != left.primary_key.lower()
-            and join_key.lower() != left.secondary_key.lower()
-        ):
-            raise ValueError(
-                "Join key is not present in left feature set as primary or secondary key!"
-            )
-        if (
-            join_key.lower() != right.primary_key.lower()
-            and join_key.lower() != right.secondary_key.lower()
-        ):
-            raise ValueError(
-                "Join key is not present in right feature set as primary or secondary key!"
-            )
-
-
 class CSVFolder:
     def __init__(self, root_folder, partition_pattern="", delimiter=","):
         self.root_folder = root_folder
@@ -357,16 +310,6 @@ def get_raw_data_location(source):
             jdbc.upper_bound = source.partition_options.upper_bound
             jdbc.fetch_size = source.partition_options.fetch_size
         raw_data_location.jdbc.CopyFrom(jdbc)
-    elif isinstance(source, DriverlessAIMOJO):
-        mojo = pb.DriverlessAIMOJOSpec()
-        mojo.data = source.data
-        mojo.input.CopyFrom(source.input._feature_set)
-        raw_data_location.mojo.CopyFrom(mojo)
-    elif isinstance(source, SparkPipeline):
-        spark_pipeline = pb.SparkPipelineSpec()
-        spark_pipeline.data = source.data
-        spark_pipeline.input.CopyFrom(source.input._feature_set)
-        raw_data_location.spark_pipeline.CopyFrom(spark_pipeline)
     elif isinstance(source, DeltaTable):
         delta_table = pb.DeltaTableSpec()
         delta_table.path = source.path
@@ -376,12 +319,6 @@ def get_raw_data_location(source):
         if source.filter:
             delta_table.filter.CopyFrom(source.filter._filter)
         raw_data_location.delta_table.CopyFrom(delta_table)
-    elif isinstance(source, JoinedFeatureSets):
-        joined_fs = pb.JoinedFeatureSetsSpec()
-        joined_fs.left.CopyFrom(source.left._feature_set)
-        joined_fs.right.CopyFrom(source.right._feature_set)
-        joined_fs.join_key = source.join_key
-        raw_data_location.joined_feature_sets.CopyFrom(joined_fs)
     elif isinstance(source, CSVFolder):
         csv_folder = pb.CSVFolderSpec()
         csv_folder.root_folder = source.root_folder
