@@ -1,13 +1,24 @@
-from featurestore.core.schema import FeatureSchema, Schema
-
+from ..schema import FeatureSchema, Schema, SchemaDerivation, VersionedId
+from ..transformations import Transformation
 from .base_job import BaseJob
 
 
 class ExtractSchemaJob(BaseJob):
     def _response_method(self, job_id):
         response = self._stub.GetExtractSchemaJobOutput(job_id)
+        derivation = None
+        if response.derived_from.HasField("transformation"):
+            derivation = SchemaDerivation(
+                [
+                    VersionedId(f.id, f.major_version)
+                    for f in response.derived_from.feature_set_ids
+                ],
+                Transformation.from_proto(response.derived_from.transformation),
+            )
         return Schema(
-            ExtractSchemaJob._features_schema_from_proto(response.schema), True
+            ExtractSchemaJob._features_schema_from_proto(response.schema),
+            True,
+            derivation,
         )
 
     @staticmethod
