@@ -1,6 +1,7 @@
 import time
 
-from .. import CoreService_pb2 as pb
+import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
+
 from ..collections.feature_sets import FeatureSets
 from ..utils import Utils
 from .user import User
