@@ -1,4 +1,4 @@
-from ..base import ArrayField, BooleanField, NumericField, StringField
+from ..base import ArrayField, BooleanField, StringField
 
 
 class FeatureSet(object):
