@@ -1,4 +1,4 @@
-from . import CoreService_pb2 as pb
+from ai.h2o.featurestore.api.v1 import CoreService_pb2 as pb
 
 INGEST = pb.JobType.Ingest
 RETRIEVE = pb.JobType.Retrieve
