@@ -5,7 +5,8 @@ from concurrent.futures import ThreadPoolExecutor
 
 import requests
 
-from . import CoreService_pb2 as pb
+from ai.h2o.featurestore.api.v1 import CoreService_pb2 as pb
+
 from .commons.spark_utils import SparkUtils
 from .job_info import JobInfo
 
@@ -150,7 +151,10 @@ class RetrieveHolder(RetrieveAsLinksCommon):
             output_df = df.filter(
                 col("time_travel_column_auto_generated") <= end_timestamp
             ).filter(col("time_travel_column_auto_generated") >= start_timestamp)
-        return output_df.drop("ingest_id")
+        internal_columns = ["ingest_id"] + [
+            column for column in df.columns if column.startswith("__")
+        ]
+        return output_df.drop(*internal_columns)
 
     def _create_retrieve_request(self, spark_session=None):
         session_id = ""
